@@ -2,4 +2,4 @@
 This module contains the implementations which is extended from the original implementation of :class:`enum.Enum`.
 """
 from .main import *  # noqa
-from .mongo import register_encoder  # noqa
+from .mongo import get_codec_options  # noqa
